@@ -14,6 +14,7 @@ __all__ = [
     "call",
     "broadcast",
     "call_batch",
+    "interactive",
     "ExecutionInfo",
     "ExecutorConfig",
     "llm",
@@ -41,11 +42,11 @@ from railtracks.built_nodes.easy_usage_wrappers import (
 from . import context, integrations, llm, prebuilt
 from ._session import ExecutionInfo, Session, session
 from .context.central import session_id, set_config
-from .interaction import broadcast, call, call_batch
+from .interaction import broadcast, call, call_batch, interactive
 from .nodes.manifest import ToolManifest
 from .rt_mcp import MCPHttpParams, MCPStdioParams, connect_mcp, create_mcp_server
 from .utils.config import ExecutorConfig
 
 load_dotenv()
 # Do not worry about changing this version number manually. It will updated on release.
-__version__ = "1.1.8"
+__version__ = "1.1.9"
