@@ -11,7 +11,15 @@ from .models import (
     OllamaLLM,
     OpenAILLM,
 )
-from .tools import Parameter, Tool
+from .models.providers import ModelProvider
+from .tools import (
+    ArrayParameter,
+    ObjectParameter,
+    Parameter,
+    RefParameter,
+    Tool,
+    UnionParameter,
+)
 
 __all__ = [
     "ModelBase",
@@ -23,8 +31,8 @@ __all__ = [
     "Message",
     "ToolMessage",
     "MessageHistory",
+    "ModelProvider",
     "Tool",
-    "Parameter",
     "AnthropicLLM",
     "AzureAILLM",
     "CohereLLM",
@@ -32,4 +40,12 @@ __all__ = [
     "OpenAILLM",
     "GeminiLLM",
     "OllamaLLM",
+    "AzureAILLM",
+    "GeminiLLM",
+    # Parameter types
+    "Parameter",
+    "UnionParameter",
+    "ArrayParameter",
+    "ObjectParameter",
+    "RefParameter",
 ]
