@@ -1,3 +1,4 @@
+from ..providers import ModelProvider
 from ._provider_wrapper import ProviderLLMWrapper
 
 
@@ -8,4 +9,4 @@ class CohereLLM(ProviderLLMWrapper):
 
     @classmethod
     def model_type(cls) -> str:
-        return "cohere_chat"
+        return ModelProvider.COHERE
