@@ -1,3 +1,4 @@
+from ..providers import ModelProvider
 from ._provider_wrapper import ProviderLLMWrapper
 
 
@@ -7,5 +8,5 @@ class GeminiLLM(ProviderLLMWrapper):
         return f"gemini/{model_name}"
 
     @classmethod
-    def model_type(cls) -> str:
-        return "Vertex_AI"  # litellm uses this for the provider for Gemini, we are using this in the checks in _provider_wrapper.py
+    def model_type(cls):
+        return ModelProvider.GEMINI  # litellm uses this for the provider for Gemini, we are using this in the checks in _provider_wrapper.py
